@@ -11,6 +11,7 @@
 
 #include <cstdint>
 #include <ostream>
+#include <vector>
 
 #include "real.h"
 
@@ -21,17 +22,30 @@ class QMatrix;
 
 class Vector {
 
+  protected:
+    std::vector<real> data_;
+
   public:
-    int64_t m_;
-    real* data_;
-
     explicit Vector(int64_t);
-    ~Vector();
+    Vector(const Vector&) = delete;
+    Vector& operator=(const Vector&) = delete;
 
-    real& operator[](int64_t);
-    const real& operator[](int64_t) const;
+    inline real* data() {
+      return data_.data();
+    }
+    inline const real* data() const {
+      return data_.data();
+    }
+    inline real& operator[](int64_t i) {
+      return data_[i];
+    }
+    inline const real& operator[](int64_t i) const {
+      return data_[i];
+    }
 
-    int64_t size() const;
+    inline int64_t size() const {
+      return data_.size();
+    }
     void zero();
     void mul(real);
     real norm() const;
